import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useState, memo } from "react";
import { Box, ButtonBase, IconButton, Menu, MenuItem, Tooltip } from "@mui/material";
import MenuIcon from "@mui/icons-material/Menu";
import UploadIcon from "@mui/icons-material/FileUpload";
import PdfIcon from "@mui/icons-material/PictureAsPdf";
import SaveIcon from "@mui/icons-material/Save";
import UndoIcon from "@mui/icons-material/Undo";
import FullscreenIcon from "@mui/icons-material/Fullscreen";
import FullscreenExitIcon from "@mui/icons-material/FullscreenExit";
import CloudIcon from "@mui/icons-material/CloudOutlined";
import InfoIcon from "@mui/icons-material/Info";
import RefreshIcon from "@mui/icons-material/Refresh";
import ButtonWithTooltip from "../ButtonWithTooltip";
import useKey from "use-key-hook";

var Header = function Header(_ref) {
  var _state$images$state$s;

  var history = _ref.history,
      onRestoreHistory = _ref.onRestoreHistory,
      dispatch = _ref.dispatch,
      onExit = _ref.onExit,
      state = _ref.state,
      fullScreenHandle = _ref.fullScreenHandle,
      onUploadImage = _ref.onUploadImage,
      hideFullScreen = _ref.hideFullScreen,
      headerButtons = _ref.headerButtons;
  var menuItems = [{
    icon: UploadIcon,
    label: "Upload Image",
    disabled: !onUploadImage ? true : false
  }, {
    icon: PdfIcon,
    label: "Preview as PDF",
    disabled: true
  }];

  var _useState = useState(null),
      _useState2 = _slicedToArray(_useState, 2),
      anchorEl = _useState2[0],
      setAnchorEl = _useState2[1];

  var open = Boolean(anchorEl);

  var handleClick = function handleClick(event) {
    setAnchorEl(event.currentTarget);
  };

  var handleClose = function handleClose() {
    setAnchorEl(null);
  };

  var getSubString = function getSubString(text, max) {
    return text.length > max ? text.slice(0, max) + "..." : text;
  };

  useKey(function (key, event) {
    switch (key) {
      case 82:
      case 114:
        var selectedImage = state.selectedImage;
        dispatch({
          type: "SELECT_IMAGE",
          imageIndex: state.images.length - 1,
          image: state.images[state.images.length - 1]
        });
        setTimeout(function () {
          dispatch({
            type: "SELECT_IMAGE",
            imageIndex: selectedImage,
            image: state.images[selectedImage]
          });
        }, 0);
        break;

      default:
        // console.log(key)
        break;
    }
  }, {
    detectKeys: [82, 114]
  }, {
    dependencies: [state]
  });
  return React.createElement(React.Fragment, null, React.createElement(Box, {
    id: "headerBar",
    sx: {
      borderBottom: "1px solid #a8a8a8",
      display: "flex",
      alignItems: "center",
      gap: "8px"
    }
  }, React.createElement(IconButton, {
    onClick: handleClick,
    sx: {
      ml: "4px"
    }
  }, React.createElement(MenuIcon, null)), React.createElement(Menu, {
    container: document.querySelector(".fullscreen"),
    anchorOrigin: {
      vertical: "bottom",
      horizontal: "left"
    },
    transformOrigin: {
      vertical: "top",
      horizontal: "left"
    },
    anchorEl: anchorEl,
    open: open,
    onClose: handleClose,
    PaperProps: {
      style: {// backgroundColor: "#e9e9e9",
      }
    },
    MenuListProps: {
      style: {
        display: "flex",
        flexDirection: "column",
        flex: 1
      }
    }
  }, menuItems.map(function (item, index) {
    return React.createElement(MenuItem, {
      key: index,
      disabled: item.disabled,
      onClick: function onClick() {
        onUploadImage();
        handleClose();
      },
      sx: {
        fontSize: "15px",
        display: "flex",
        alignItems: "center",
        gap: "8px"
      }
    }, React.createElement(item.icon, {
      sx: {
        color: "#757575"
      }
    }), item.label);
  })), React.createElement(ButtonWithTooltip, {
    tooltipText: "Save",
    disabled: history.length === 0,
    onClick: function onClick() {
      fullScreenHandle.exit();
      onExit(_objectSpread({}, state, {
        images: state.images.slice(0, state.images.length - 1)
      }));
    },
    Icon: SaveIcon
  }), React.createElement(ButtonWithTooltip, {
    tooltipText: "Undo (Ctrl+Z)",
    disabled: history.length === 0,
    onClick: function onClick() {
      return onRestoreHistory();
    },
    Icon: UndoIcon
  }), React.createElement(ButtonWithTooltip, {
    tooltipText: "Reset Image (R)",
    onClick: function onClick() {
      var selectedImage = state.selectedImage;
      dispatch({
        type: "SELECT_IMAGE",
        imageIndex: state.images.length - 1,
        image: state.images[state.images.length - 1]
      });
      setTimeout(function () {
        dispatch({
          type: "SELECT_IMAGE",
          imageIndex: selectedImage,
          image: state.images[selectedImage]
        });
      }, 0);
    },
    Icon: RefreshIcon
  }), state.mode && (state.mode.mode === "DRAW_POLYLINE" || state.mode.mode === "DRAW_POLYGON") ? React.createElement(Box, {
    sx: {
      display: "flex",
      alignItems: "center",
      gap: "6px",
      fontSize: "13px",
      fontWeight: "bold",
      borderRadius: "6px",
      bgcolor: "#fff" // border: "1px solid #a8a8a8",
      // p: "4px",
      // my: "4px",
      // boxShadow: "rgba(0, 0, 0, 0.35) 0px 5px 15px",

    }
  }, React.createElement(InfoIcon, {
    sx: {
      color: "orange"
    }
  }), "Press \"X\" to complete the", " ", state.mode.mode.split("_").at(-1).toLowerCase(), ", \"C\" to cancel") : null, React.createElement(Box, {
    sx: {
      display: "flex",
      alignItems: "center",
      gap: "10px",
      fontWeight: "bold",
      mx: "auto",
      fontSize: "13px"
    }
  }, React.createElement(CloudIcon, {
    sx: {
      color: "#757575"
    }
  }), (_state$images$state$s = state.images[state.selectedImage]) === null || _state$images$state$s === void 0 ? void 0 : _state$images$state$s.name), React.createElement(Box, {
    sx: {
      ml: "auto",
      mr: "10px",
      display: "flex",
      gap: "6px"
    }
  }, !hideFullScreen && React.createElement(Tooltip, {
    title: state.fullScreen ? "Window" : "Fullscreen"
  }, React.createElement(IconButton, {
    onClick: function onClick() {
      if (state.fullScreen) {
        fullScreenHandle.exit();
        dispatch({
          type: "HEADER_BUTTON_CLICKED",
          buttonName: "window"
        });
      } else {
        fullScreenHandle.enter();
        dispatch({
          type: "HEADER_BUTTON_CLICKED",
          buttonName: "fullscreen"
        });
      }
    }
  }, state.fullScreen ? React.createElement(FullscreenExitIcon, null) : React.createElement(FullscreenIcon, null))), headerButtons && headerButtons.map(function (Button, i) {
    return React.createElement("div", {
      key: i
    }, Button);
  }))), React.createElement(Box, {
    sx: {
      ml: "50px",
      display: "flex",
      alignItems: "center",
      overflow: "hidden",
      overflowX: "auto",
      // borderRight: "1px solid #a8a8a8",
      "&::-webkit-scrollbar-thumb:hover": {
        backgroundColor: "#555"
      },
      "&::-webkit-scrollbar-track": {
        // borderRadius: "4px",
        backgroundColor: "#f5f5f5",
        WebkitBoxShadow: "inset 0 0 6px rgba(0,0,0,0.3)"
      },
      "&::-webkit-scrollbar": {
        height: "6px",
        backgroundColor: "#f5f5f5"
      },
      "&::-webkit-scrollbar-thumb": {
        // borderRadius: "4px",
        backgroundColor: "#afb5b8",
        WebkitBoxShadow: "inset 0 0 6px rgba(0,0,0,0.3)"
      }
    }
  }, state.images.slice(0, state.images.length - 1).map(function (img, i) {
    return React.createElement(ButtonBase, {
      title: img.name,
      onClick: function onClick() {
        dispatch({
          type: "SELECT_IMAGE",
          imageIndex: i,
          image: state.images[i]
        });
      },
      key: i,
      sx: {
        // borderRadius: "2px",
        whiteSpace: "nowrap",
        borderBottom: "4px solid #a8a8a8",
        borderLeft: "1px solid #a8a8a8",
        borderRight: "1px solid #a8a8a8",
        borderBottomColor: state.selectedImage === i && "#2c88d9",
        p: "8px",
        boxShadow: state.selectedImage === i && "rgba(0, 0, 0, 0.25) 0px 54px 55px, rgba(0, 0, 0, 0.12) 0px -12px 30px, rgba(0, 0, 0, 0.12) 0px 4px 6px, rgba(0, 0, 0, 0.17) 0px 12px 13px, rgba(0, 0, 0, 0.09) 0px -3px 5px",
        transition: "all 0.4s ease",
        fontFamily: "Quicksand",
        fontSize: "13px",
        fontWeight: "600"
      }
    }, getSubString(img.name, "12"));
  })));
};

export default memo(Header);